## SNP1 

this package can be installed by going to command prompt and type the following command:
             pip install SNP1
             
this package can be used to find the AP and GP progression series and sum.
the package has 4 modules namely:-
        AP()
        APsum()
        GP()
        GPsum()

AP(a,d,n)

this module provides the AP series , the required inputs are 
a- starting term
d- common difference
n- number of terms

the output will be in print form

APsum(a,d,n)

this module provides the AP sum , the required inputs are
a- starting term
d- common difference
n- number of terms

the output will be in print form

GP(a,r,n)

this module provides the GP series, the required inputs are 
a- starting term
r- common ratio
n- number of terms

the output will be in print form

GPsum(a,r,n)

this module provides the GP sum , the required inputs are

a- starting term
r- common ratio
n- number of terms

the output is in print form
